@@ -30,20 +30,33 @@ from zope.app.container.contained import (
     IContainerModifiedEvent, ContainerModifiedEvent)
 
 from martian import ClassGrokker, InstanceGrokker, GlobalGrokker
-from grok.components import Model, Adapter, MultiAdapter, View, XMLRPC, JSON
-from grok.components import PageTemplate, PageTemplateFile, Container, Traverser
-from grok.components import Site, GlobalUtility, LocalUtility, Annotation
+from grokcore.component import Adapter, MultiAdapter, GlobalUtility
+from grok.components import Model, View
+from grok.components import XMLRPC, REST, JSON
+from grok.components import PageTemplate, PageTemplateFile, Traverser
+from grok.components import Container, OrderedContainer
+from grok.components import Site, LocalUtility, Annotation
 from grok.components import Application, Form, AddForm, EditForm, DisplayForm
 from grok.components import Indexes
-from grok.directive import (context, name, template, templatedir, provides,
-                            baseclass, global_utility, local_utility,
-                            define_permission, require, site)
-from grok._grok import do_grok as grok  # Avoid name clash within _grok
-from grok._grok import grok_component
-from grok._grok import SubscribeDecorator as subscribe
-from grok._grok import adapter, implementer
+from grok.components import Permission, Role, Public
+from grok.components import Skin, IGrokLayer
+from grok.components import RESTProtocol, IRESTLayer
+from grok.interfaces import IRESTSkinType
+from grok.components import ViewletManager, Viewlet
+
+from martian import baseclass
+from grokcore.component.directive import (
+    context, name, title, description, provides, global_utility, direct)
+from grok.directive import (
+    template, templatedir, local_utility, permissions, require, site,
+    layer, viewletmanager, view, traversable, order)
+from grokcore.component.decorators import subscribe, adapter, implementer
 from martian.error import GrokError, GrokImportError
 
+# BBB These two functions are meant for test fixtures and should be
+# imported from grok.testing, not from grok.
+from grok.testing import grok, grok_component
+
 from grok.formlib import action, AutoFields, Fields
 from grok.util import url
 
