@@ -1,9 +1,6 @@
 """
 A grok.EditForm is a special grok.View that renders an edit form.
 
-  >>> import grok
-  >>> from grok.ftests.form.form import Mammoth
-  >>> grok.grok('grok.ftests.form.form')
   >>> getRootFolder()["manfred"] = Mammoth()
 
   >>> from zope.testbrowser.testing import Browser
@@ -31,14 +28,22 @@ grok.DisplayForm renders a display form:
 """
 import grok
 from zope import schema
+from zope.interface import Interface, implements
+from zope.schema.fieldproperty import FieldProperty
+
+class IMammoth(Interface):
+    name = schema.TextLine(title=u"Name")
+    size = schema.TextLine(title=u"Size", default=u"Quite normal")
 
 class Mammoth(grok.Model):
-    class fields:
-        name = schema.TextLine(title=u"Name")
-        size = schema.TextLine(title=u"Size")
+    implements(IMammoth)
+    
+    name = FieldProperty(IMammoth['name'])    
+    size = FieldProperty(IMammoth['size'])    
 
 class Edit(grok.EditForm):
     pass
 
 class Display(grok.DisplayForm):
     pass
+
