@@ -1,11 +1,12 @@
 """
 Templates with ambiguous context cannot be grokked:
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
   Traceback (most recent call last):
     ...
   GrokError: Multiple possible contexts for
-  <class 'grok.tests.view.ambiguouscontext.Club'>, please use grok.context.
+  <class 'grok.tests.view.ambiguouscontext.Club'>, please use the
+  'context' directive.
 
 """
 
