@@ -1,7 +1,7 @@
 """
 Templates can also be found in a directory with the same name as the module:
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
   
   >>> manfred = Mammoth()
   >>> from zope.publisher.browser import TestRequest
