@@ -1,12 +1,13 @@
 """
 Only one, either a template, or render() can be specified:
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
   Traceback (most recent call last):
     ...
-  GrokError: Multiple possible ways to render view
+  ConfigurationExecutionError: martian.error.GrokError: Multiple possible ways to render view
   <class 'grok.tests.view.eithertemplateorrender.CavePainting'>.
   It has both a 'render' method as well as an associated template.
+  in:
 """
 import grok
 
