@@ -1,11 +1,12 @@
 """
 Views without a context cannot be grokked:
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
   Traceback (most recent call last):
     ...
   GrokError: No module-level context for
-  <class 'grok.tests.view.missingcontext.Club'>, please use grok.context.
+  <class 'grok.tests.view.missingcontext.Club'>, please use the
+  'context' directive.
 
 """
 
