@@ -1,6 +1,6 @@
 """
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
 
 View with an associated PageTemplate that is referred to using
 ``grok.template``:
@@ -27,5 +27,5 @@ class Mammoth(grok.Model):
 class Food(grok.View):
     pass
 
-food = grok.PageTemplateFile(os.path.join('templatedirectoryname',
-                                          'food.pt'))
+food = grok.PageTemplate(filename=os.path.join('templatedirectoryname',
+                                               'food.pt'))
